@@ -18,8 +18,8 @@
 
 #include <QHBoxLayout>
 
-#include <KMenu>
-#include <KIcon>
+#include <QMenu>
+#include <QIcon>
 #include <KLocale>
 
 #include "wlmchatsessioninkarea.h"
@@ -30,7 +30,7 @@ class WlmChatSessionInkAction::WlmChatSessionInkActionPrivate
 public:
     WlmChatSessionInkActionPrivate()
     {
-        m_popup = new KMenu(0L);
+        m_popup = new QMenu(0L);
         m_sessionInk = new QWidget;
         Ui::InkWindow ui;
         ui.setupUi(m_sessionInk);
@@ -48,18 +48,17 @@ public:
         m_sessionInk = 0;
     }
 
-    KMenu *m_popup;
+    QMenu *m_popup;
     QWidget *m_sessionInk;
 };
 
-
 WlmChatSessionInkAction::WlmChatSessionInkAction( QObject* parent )
   : KActionMenu( i18n( "Send Ink" ), parent )
 {
     d = new WlmChatSessionInkActionPrivate;
     setMenu( d->m_popup );
     
-    setIcon( KIcon("application-pgp-signature") );
+    setIcon( QIcon::fromTheme(QStringLiteral("application-pgp-signature")) );
     QList<WlmChatSessionInkArea *> sessionInkList = d->m_sessionInk->findChildren<WlmChatSessionInkArea *>();
     WlmChatSessionInkArea *inkArea = sessionInkList.first();
     if(inkArea)
@@ -82,4 +81,3 @@ WlmChatSessionInkAction::~WlmChatSessionInkAction()
     d = NULL;
 }
 
-#include "wlmchatsessioninkaction.moc"
